@@ -7,4 +7,6 @@ from .lib.profiles import *
 from .lib.luks import *
 from .lib.mirrors import *
 from .lib.networking import *
-from .lib.locale_helpers import *
\ No newline at end of file
+from .lib.locale_helpers import *
+from .lib.services import *
+from .lib.packages import *
\ No newline at end of file
