@@ -1,13 +1,23 @@
 import archinstall, getpass, time
 
-def perform_installation(device, boot_partition, language):
+def perform_installation(device, boot_partition, language, mirrors):
 	"""
 	Performs the installation steps on a block device.
 	Only requirement is that the block devices are
 	formatted and setup prior to entering this function.
 	"""
 	with archinstall.Installer(device, boot_partition=boot_partition, hostname=hostname) as installation:
+		## if len(mirrors):
+		# Certain services might be running that affects the system during installation.
+		# Currently, only one such service is "reflector.service" which updates /etc/pacman.d/mirrorlist
+		# We need to wait for it before we continue since we opted in to use a custom mirror/region.
+		archinstall.log(f'Waiting for automatic mirror selection has completed before using custom mirrors.')
+		while 'dead' not in (status := archinstall.service_state('reflector')):
+			time.sleep(1)
+
+		archinstall.use_mirrors(mirrors) # Set the mirrors for the live medium
 		if installation.minimal_installation():
+			installation.set_mirrors(mirrors) # Set the mirrors in the installation medium
 			installation.set_keyboard_language(language)
 			installation.add_bootloader()
 
@@ -27,9 +37,6 @@ def perform_installation(device, boot_partition, language):
 			if root_pw:
 				installation.user_set_pw('root', root_pw)
 
-			if len(aur.strip()) and aur.strip().lower() != 'no':
-				installation.add_AUR_support()
-
 # Unmount and close previous runs (in case the installer is restarted)
 archinstall.sys_command(f'umount -R /mnt', surpress_errors=True)
 archinstall.sys_command(f'cryptsetup close /dev/mapper/luksloop', surpress_errors=True)
@@ -43,6 +50,9 @@ archinstall.sys_command(f'cryptsetup close /dev/mapper/luksloop', surpress_error
 keyboard_language = archinstall.select_language(archinstall.list_keyboard_languages())
 archinstall.set_keyboard_language(keyboard_language)
 
+# Set which region to download packages from during the installation
+mirror_regions = archinstall.select_mirror_regions(archinstall.list_mirrors())
+
 harddrive = archinstall.select_disk(archinstall.all_disks())
 while (disk_password := getpass.getpass(prompt='Enter disk encryption password (leave blank for no encryption): ')):
 	disk_password_verification = getpass.getpass(prompt='And one more time for verification: ')
@@ -82,14 +92,19 @@ while 1:
 	users[new_user] = new_user_passwd
 	break
 
-aur = input('Would you like AUR support? (leave blank for no): ')
-if len(aur.strip()) and aur.lower() != 'no':
-	archinstall.log(' - AUR support provided by yay (https://aur.archlinux.org/packages/yay/)', bg='black', fg='white')
+while 1:
+	profile = archinstall.select_profile(archinstall.list_profiles())
+	if type(profile) != str: # Got a imported profile
+		if not profile[1]._prep_function():
+			archinstall.log(' * Profile\'s preperation requirements was not fulfilled.', bg='black', fg='red')
+			continue
+		profile = profile[0]._path # Once the prep is done, replace the selected profile with the profile name ("path") given from select_profile()
+		break
+	else:
+		break
 
-profile = input('Any particular profile you want to install: ')
 packages = input('Additional packages aside from base (space separated): ').split(' ')
 
-
 """
 	Issue a final warning before we continue with something un-revertable.
 """
@@ -126,7 +141,7 @@ with archinstall.Filesystem(harddrive, archinstall.GPT) as fs:
 		with archinstall.luks2(harddrive.partition[1], 'luksloop', disk_password) as unlocked_device:
 			unlocked_device.format('btrfs')
 			
-			perform_installation(unlocked_device, harddrive.partition[0], keyboard_language)
+			perform_installation(unlocked_device, harddrive.partition[0], keyboard_language, mirror_regions)
 	else:
 		harddrive.partition[1].format('ext4')
-		perform_installation(harddrive.partition[1], harddrive.partition[0], keyboard_language)
\ No newline at end of file
+		perform_installation(harddrive.partition[1], harddrive.partition[0], keyboard_language, mirror_regions)
\ No newline at end of file
