@@ -36,7 +36,7 @@ def list_profiles(base='./profiles/', filter_irrelevant_macs=True):
 					if first_line[0] == '#':
 						description = first_line[1:].strip()
 
-				cache[file[:-2]] = {'path' : os.path.join(root, file), 'description' : description, 'tailored' : tailored}
+				cache[file[:-3]] = {'path' : os.path.join(root, file), 'description' : description, 'tailored' : tailored}
 		break
 	return cache
 
@@ -47,7 +47,7 @@ class Imported():
 
 	def __enter__(self, *args, **kwargs):
 		self.spec.loader.exec_module(self.imported)
-		return self
+		return self.imported
 
 	def __exit__(self, *args, **kwargs):
 		# TODO: https://stackoverflow.com/questions/28157929/how-to-safely-handle-an-exception-inside-a-context-manager
@@ -82,15 +82,17 @@ class Profile():
 
 		return None
 
-	def py_exec_mock(self):
-		spec.loader.exec_module(imported)
+#	def py_exec_mock(self):
+#		spec.loader.exec_module(imported)
 
-	def load_instructions(self):
+	def load_instructions(self, namespace=None):
 		if (absolute_path := self.path):
 			if os.path.splitext(absolute_path)[1] == '.py':
-				spec = importlib.util.spec_from_file_location(absolute_path, absolute_path)
+				if not namespace:
+					namespace = os.path.splitext(os.path.basename(absolute_path))[0]
+				spec = importlib.util.spec_from_file_location(namespace, absolute_path)
 				imported = importlib.util.module_from_spec(spec)
-				sys.modules[os.path.basename(absolute_path)] = imported
+				sys.modules[namespace] = imported
 				return Imported(spec, imported)
 			else:
 				raise ProfileError(f'Extension {os.path.splitext(absolute_path)[1]} is not a supported profile model. Only .py is supported.')
